# Trenchrun


This tool computes the [Meridian Trench
Run](https://starwars.fandom.com/wiki/Meridian_trench) image for a scene using
[Whitebox Tools](https://github.com/jblindsay/whitebox-tools/),
[PDAL](https://pdal.io), and matplotlib.

![Meridian Trench](/images/meridian.png)

![Autzen Trenchrun Image](/images/autzen-exposure.jpg)

